@@ -16,6 +16,10 @@ class PhotoAdminForm(admin.ModelAdmin):
 
     def save_model(self, request, obj, form, change):
         expire_view_cache("app_gallery-gallery")
+        folders = mymodels.Folder.objects.all()
+        if folders is not None:
+            for f in folders:
+                expire_view_cache("app_gallery-folder", [f.slug])
         obj.save()
 
 
